/********************************************************************
 FileName:    	BSP.h
 Dependencies: 	none
 Hardware:	Aguijon rev3.0 & rev4.0
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Board Support Package


 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             JCOG
  2.0   Updated with [VD] HammerHead libraries      JCOG
  2.1   Added support for Aguijon PRO               JCOG

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/

#ifndef AGUIJON_BSP_H
#define	AGUIJON_BSP_H

#define ON    TRUE
#define OFF   FALSE

#if defined(AGUIJON_REV_3)

    //opto isolated inputs
    #define INPUT1          PORTBbits.RB0
    #define INPUT2          PORTBbits.RB1
    #define INPUT3          PORTBbits.RB2
    #define INPUT4          PORTBbits.RB3

    //On board switches & DIP Switch (shared)
    #define SWITCH1         PORTBbits.RB13  //SWITCH 1 is shared with DIP 4 & 8
    #define SWITCH2         PORTBbits.RB12  //SWITCH 2 is shared with DIP 3 & 7
    #define SWITCH3         PORTBbits.RB11  //SWITCH 3 is shared with DIP 2 & 6
    #define SWITCH4         PORTBbits.RB10  //SWITCH 4 is shared with DIP 1 & 5

    #define DIPSW_KEY_1_5   PORTBbits.RB10  //DIP SW keys 1 & 5 are shared
    #define DIPSW_KEY_2_6   PORTBbits.RB11  //DIP SW keys 2 & 6 are shared
    #define DIPSW_KEY_3_7   PORTBbits.RB12  //DIP SW keys 3 & 7 are shared
    #define DIPSW_KEY_4_8   PORTBbits.RB13  //DIP SW keys 4 & 8 are shared

    #define DIPSW_ENABLE_LSB_PIN  LATFbits.LATF1  //Control lines to allow sharing
    #define DIPSW_ENABLE_MSB_PIN  LATFbits.LATF0  //Control lines to allow sharing

    #define KEYBOARD_MASK           0x3C00
    #define INPUT_MASK              0x000F

    //end of input definitions

    //Analog
    #define ADC_PIN      15
    #define ADC_PIN_MASK 0x7FFF

    //LCD
    #define LCD_RESET_PIN   LATDbits.LATD11
    #define LCD_BLIGHT_PIN  LATGbits.LATG6

    //Relays
    #define RLY1_SET  LATDbits.LATD7
    #define RLY2_SET  LATDbits.LATD6
    #define RLY3_SET  LATDbits.LATD5
    #define RLY4_SET  LATDbits.LATD4

    #define RLY1_READ PORTDbits.RD7
    #define RLY2_READ PORTDbits.RD6
    #define RLY3_READ PORTDbits.RD5
    #define RLY4_READ PORTDbits.RD4

    //Open Collector
    #define OC1_SET   LATDbits.LATD3
    #define OC2_SET   LATDbits.LATD2
    #define OC3_SET   LATDbits.LATD1
    #define OC4_SET   LATDbits.LATD0

    #define OC1_READ  PORTDbits.RD3
    #define OC2_READ  PORTDbits.RD2
    #define OC3_READ  PORTDbits.RD1
    #define OC4_READ  PORTDbits.RD0

    //LED port
    #define LED1_SET  LATEbits.LATE0
    #define LED2_SET  LATEbits.LATE1
    #define LED3_SET  LATEbits.LATE2
    #define LED4_SET  LATEbits.LATE3
    #define LED5_SET  LATEbits.LATE4
    #define LED6_SET  LATEbits.LATE5
    #define LED7_SET  LATEbits.LATE6
    #define LED8_SET  LATEbits.LATE7

    #define LED1_READ PORTEbits.RE0
    #define LED2_READ PORTEbits.RE1
    #define LED3_READ PORTEbits.RE2
    #define LED4_READ PORTEbits.RE3
    #define LED5_READ PORTEbits.RE4
    #define LED6_READ PORTEbits.RE5
    #define LED7_READ PORTEbits.RE6
    #define LED8_READ PORTEbits.RE7

    //USB
    #define USB_5V_ENABLE   LATGbits.LATG9
    #define USB_5V_FAULT    PORTGbits.RG8

    #define USB_5V_ENABLE_TRIS  TRISGbits.TRISG9
    #define USB_5V_FAULT_TRIS   TRISGbits.TRISG8

    //SPI
    #define EXT_INT_PIN         PORTDbits.RD8
    #define EXT_INT_TRIS        TRISDbits.TRISD8

    #define PHY_CS              LATFbits.LATF5
    #define PHY_CS_TRIS         TRISFbits.TRISF5
    #define PHY_RESETn          LATFbits.LATF4
    #define PHY_RESETn_TRIS     TRISFbits.TRISF4

    #define SPI_SDO             PORTBbits.RB5
    #define SDO_TRIS            TRISBbits.TRISB5
    #define SPI_SDI             LATBbits.LATB14
    #define SDI_TRIS            TRISBbits.TRISB14
    #define SPI_SCK             LATBbits.LATB4
    #define SCK_TRIS            TRISBbits.TRISB4

#elif defined(AGUIJON_REV_4)
    //opto isolated inputs
    #define INPUT1  PORTAbits.RA9
    #define INPUT2  PORTEbits.RE9
    #define INPUT3  PORTEbits.RE8
    #define INPUT4  PORTCbits.RC3
    
    //On board switches & DIP Switch (shared)
    #define SWITCH1         PORTBbits.RB13  //SWITCH 1 is shared with DIP 4 & 8
    #define SWITCH2         PORTBbits.RB12  //SWITCH 2 is shared with DIP 3 & 7
    #define SWITCH3         PORTBbits.RB11  //SWITCH 3 is shared with DIP 2 & 6
    #define SWITCH4         PORTBbits.RB10  //SWITCH 4 is shared with DIP 1 & 5

    #define DIPSW_KEY_1_5   PORTBbits.RB10  //DIP SW keys 1 & 5 are shared
    #define DIPSW_KEY_2_6   PORTBbits.RB11  //DIP SW keys 2 & 6 are shared
    #define DIPSW_KEY_3_7   PORTBbits.RB12  //DIP SW keys 3 & 7 are shared
    #define DIPSW_KEY_4_8   PORTBbits.RB13  //DIP SW keys 4 & 8 are shared

    #define DIPSW_ENABLE_LSB_PIN  LATFbits.LATF1  //Control lines to allow sharing
    #define DIPSW_ENABLE_MSB_PIN  LATFbits.LATF0  //Control lines to allow sharing

    #define KEYBOARD_MASK   0x3C00
    #define INPUT1_MASK     0x0200
    #define INPUT2_MASK     0x0200
    #define INPUT3_MASK     0x0100
    #define INPUT4_MASK     0x0008
    //end of input definitions

    //Watchdog & reset
    #define WDOG_PIN PORTBbits.RB7


    //Analog
    #define ADC_PIN      3
    #define ADC_PIN_MASK 0xFFF7

    //LCD
    #define LCD_RESET_PIN   LATAbits.LATA10
    #define LCD_BLIGHT_PIN  LATGbits.LATG6


    //Relays
    #define RLY1_SET  LATDbits.LATD13
    #define RLY2_SET  LATDbits.LATD12
    #define RLY3_SET  LATDbits.LATD7
    #define RLY4_SET  LATDbits.LATD6

    #define RLY1_READ PORTDbits.RD13
    #define RLY2_READ PORTDbits.RD12
    #define RLY3_READ PORTDbits.RD7
    #define RLY4_READ PORTDbits.RD6


    //Open Collector
    #define OC1_SET   LATDbits.LATD3
    #define OC2_SET   LATDbits.LATD2
    #define OC3_SET   LATDbits.LATD1
    #define OC4_SET   LATDbits.LATD0

    #define OC1_READ  PORTDbits.RD3
    #define OC2_READ  PORTDbits.RD2
    #define OC3_READ  PORTDbits.RD1
    #define OC4_READ  PORTDbits.RD0

    //LED port
    #define LED1_SET  LATEbits.LATE0
    #define LED2_SET  LATEbits.LATE1
    #define LED3_SET  LATEbits.LATE2
    #define LED4_SET  LATEbits.LATE3
    #define LED5_SET  LATEbits.LATE4
    #define LED6_SET  LATEbits.LATE5
    #define LED7_SET  LATEbits.LATE6
    #define LED8_SET  LATEbits.LATE7

    #define LED1_READ PORTEbits.RE0
    #define LED2_READ PORTEbits.RE1
    #define LED3_READ PORTEbits.RE2
    #define LED4_READ PORTEbits.RE3
    #define LED5_READ PORTEbits.RE4
    #define LED6_READ PORTEbits.RE5
    #define LED7_READ PORTEbits.RE6
    #define LED8_READ PORTEbits.RE7

    #define STATUS_LEDA_SET LATDbits.LATD14
    #define STATUS_LEDA_GET PORTDbits.RD14

    #define STATUS_LEDB_SET LATCbits.LATC1
    #define STATUS_LEDB_GET PORTCbits.RC1

    //USB
    #define USB_5V_ENABLE   LATGbits.LATG1
    #define USB_5V_FAULT    PORTGbits.RG0

    #define USB_5V_ENABLE_TRIS         TRISGbits.TRISG1
    #define USB_5V_FAULT_TRIS   TRISGbits.TRISG0


    //SPI 
    #define EXT_INT_PIN         PORTDbits.RD8
    #define EXT_INT_TRIS        TRISDbits.TRISD8

    #define PHY_CS              LATFbits.LATF5
    #define PHY_CS_TRIS         TRISFbits.TRISF5
    #define PHY_RESETn          LATFbits.LATF4
    #define PHY_RESETn_TRIS     TRISFbits.TRISF4

    #define SPI_SDO             PORTBbits.RB5
    #define SDO_TRIS            TRISBbits.TRISB5
    #define SPI_SDI             LATBbits.LATB14
    #define SDI_TRIS            TRISBbits.TRISB14
    #define SPI_SCK             LATBbits.LATB4
    #define SCK_TRIS            TRISBbits.TRISB4
#endif

#endif	/* AGUIJON_BSP_H */

