/********************************************************************
 FileName:    	EEPROM.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0 & rev4.0
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    1kbit EEPROM Support File


 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             JCOG
  2.0   Updated with [VD] HammerHead libraries      JCOG
  2.1   Added support for Aguijon PRO               JCOG

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "EEPROM.h"
#include "IO.h"




///////////////////////////////////////
unsigned char EEPROM_Read(unsigned char address)
{
    unsigned char eeData=0;

    if(address > EEPROM_SIZE){ return 255; }

    IO_I2Cstart();
    IO_I2CsendByte(EEPROM_WRITE_CMD);
    IO_I2CsendByte(address);
    IO_I2Cstop();
    
    IO_I2Cstart();
    IO_I2CsendByte(EEPROM_READ_CMD);
    //let's see what the EEPROM sends us
    eeData = IO_I2CreadByte(DONT_ACK_EEPROM);
    //Send NACK
    IO_I2CsendNACK();
    IO_I2Cstop();

    return eeData;
}

BOOL EEPROM_Write(unsigned char address, unsigned char new_data)
{
    unsigned char verifyWrite = 0;

    //we limit (kind of) the maximum EEPROM address
    address &= EEPROM_SIZE;

    IO_I2Cstart();
    IO_I2CsendByte(EEPROM_WRITE_CMD);
    IO_I2CsendByte(address);
    IO_I2CsendByte(new_data);
    IO_I2Cstop();

    delayms(10);    //wait a bit

    //now, lets verify the data we've written
    verifyWrite = EEPROM_Read(address);

    delayms(10);    //wait a bit

    if(verifyWrite == new_data){
        return TRUE;    //write operation succeeded
    }else{
        return FALSE;   //write operation failed
    }
}
