/********************************************************************
 FileName:    	RS232.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0 & rev4.0
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Analog Support File


 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             JCOG
  2.0   Updated with [VD] HammerHead libraries      JCOG

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include <PPS.h>
#include <uart.h>





///////////////////////////////////////
void RS232_Init(int baud)
{
    //low baudrate, 8bit comm, no parity, 1 stop bit
    PPSUnLock;  //unlock register
    RPINR19bits.U2RXR = 8;  //assign U2RX to RP8
    RPOR4bits.RP9R    = 5;  //assign U2TX to RP9
    PPSLock;    //lock PPS register

    CloseUART2();

    IFS1bits.U2RXIF  = 0;
    IEC1bits.U2RXIE  = 1;   //enable only RX interrupt
    IPC7bits.U2RXIP2 = 0;
    IPC7bits.U2RXIP1 = 1;
    IPC7bits.U2RXIP0 = 0;

    U2MODE = 0x8000; //low baudrate, 8bit comm, no parity, 1 stop bit

    U2STA  = 0x2400;
    U2BRG  = baud;
}

void RS232_Send(unsigned int data)
{
    WriteUART2(data);
}

void RS232_PutStr(unsigned int *string)
{
    putsUART2((unsigned int*)string);
}

unsigned int RS232_Read(void)
{
    unsigned int inputData = 0;

    inputData = ReadUART2();

    return inputData;
}

/* RS232 Receive interrupt*/
void __attribute__((interrupt,__no_auto_psv__)) _U2RXInterrupt(void)
{
    unsigned char rxData = 0;

    rxData = ReadUART2();       //get received data
    RS232_Send(rxData);         //echo it
    LED8_SET = !LED8_SET;       //toggle LED8 using the global macro

    IFS1bits.U2RXIF = 0;        //clear the interrupt status of UART2 RX
}
