/********************************************************************
 FileName:    	analog.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0 & rev4.0
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Analog Support File


 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             JCOG
  2.0   Updated with [VD] HammerHead libraries      JCOG
  2.1   Added support for Aguijon PRO               JCOG

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"




///////////////////////////////////////
void ADC_Init(void)
{
    AD1PCFG          = ADC_PIN_MASK;//select RB15(AN15) as analog input
    AD1CON1          = 0x00E0;      //internal counter ends sampling and starts conversion
    AD1CON2          = 0;           //use AVDD, AVSS as reference pins
    AD1CON3          = 0x1F02;      //Tsamp = 32 x Tad; Tad=125ns
    AD1CSSL          = 0;           //no scanning required
    AD1CON1bits.ADON = 1;           //turn on the ADC
}

int ADC_Read(void)
{
    AD1CHS           = ADC_PIN; // 1. select analog input channel
    AD1CON1bits.SAMP = 1; 	// 2. start sampling
    while (!AD1CON1bits.DONE); 	// 3. wait for the conversion to complete
    return ADC1BUF0; 		// 4. read the conversion result
}

int ADC_Range(int min_val, int max_val)
{
    //not very accurate, but still works well
    float x           = 0.0;
    float preResult   = 0.0;
    int   adcReading  = 0;
    int   finalResult = 0;

    if(min_val > max_val){
        return 0;
    } //min cannot be > than max

    adcReading = ADC_Read();

    x = ADC_MAX_VALUE / (max_val - min_val);

    preResult  = (adcReading / x);
    preResult += min_val;

    finalResult = (int)(preResult);

    return finalResult;
}
