/********************************************************************
 FileName:    	outputs.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0 & rev4.0
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Outputs Support File


 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             JCOG
  2.0   Updated with [VD] HammerHead libraries      JCOG

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#define USE_AND_OR
#define ocmp_v2_3
#include "aguijon.h"
#include "outputs.h"
#include <outcompare.h>
#include <PPS.h>




///////////////////////////////////////

/*Relays*/
///////////////////////////////////////////////////////////////////////////////
BOOL RLY_Get(int num)
{
    unsigned char portData = 0;

    if(num > 4 || !num){ return FALSE; }

#if defined(AGUIJON_REV_3)
    portData   = (PORTD & (1<<(8-num)));    //check if bit is set   
    portData >>= (8-num);   //convert to BOOL
#elif defined(AGUIJON_REV_4)    
    switch(num){
        case 1: portData = RLY1_READ; break;
        case 2: portData = RLY2_READ; break;
        case 3: portData = RLY3_READ; break;
        case 4: portData = RLY4_READ; break;
    }
#endif

    return portData;
}

void RLY_Set(int num, BOOL state)
{
    if(num > 4 || !num){ return; }

    switch(num){
        case 1: if(state){ RLY1_SET = 1; }
                else     { RLY1_SET = 0; }
                break;
        case 2: if(state){ RLY2_SET = 1; }
                else     { RLY2_SET = 0; }
                break;
        case 3: if(state){ RLY3_SET = 1; }
                else     { RLY3_SET = 0; }
                break;
        case 4: if(state){ RLY4_SET = 1; }
                else     { RLY4_SET = 0; }
                break;
    }
}
///////////////////////////////////////////////////////////////////////////////

/*OpenCollector*/
///////////////////////////////////////////////////////////////////////////////
BOOL OC_Get(int num)
{
    unsigned char portData = 0;

    if(num > 4 || !num){ return FALSE; }

    portData   = (PORTD & (1<<(4-num)));    //get bit state
    portData >>= (4-num);   //convert to BOOL

    return portData;
}

void OC_Set(int num, BOOL state)
{
    if(num > 4 || !num){ return; }

    switch(num){
        case 1: if(state){ OC1_SET = 1; }
                else     { OC1_SET = 0; }
                break;
        case 2: if(state){ OC2_SET = 1; }
                else     { OC2_SET = 0; }
                break;
        case 3: if(state){ OC3_SET = 1; }
                else     { OC3_SET = 0; }
                break;
        case 4: if(state){ OC4_SET = 1; }
                else     { OC4_SET = 0; }
                break;
    }
}

void OC_PWMSet(int period, int duty_cycle)
{
    //period is given in microSeconds (uS)
    UINT32 duty        = 0;
    UINT16 fixedPeriod = 0;
    UINT16 fixedDuty   = 0;

    if(period < 8000){
        fixedDuty   = 100 - duty_cycle;
        fixedPeriod = (period * PWM_CONV_FACTOR);
    }else{
        fixedDuty   = 50;
        fixedPeriod = 1000;
    }

    CloseOC3();
    if(fixedDuty && fixedPeriod){
        duty  = fixedPeriod;
        duty *= fixedDuty;
        duty /= 100;
        OpenOC3(OC_SYSCLK_SRC  | OC_CONTINUE_PULSE, OC_SYNC_TRIG_IN_CURR_OC, fixedPeriod, duty);
    }
}

void OC_PWMChannelConfig(int num)
{
    /*  OpenCollector1 is RP22
     *  OpenCollector2 is RP23
     *  OpenCollector3 is RP24
     *  OpenCollector4 is RP11
     */
    CloseOC3();

    if(num > 4){ return; } //we only have 4 outputs

    PPSUnLock;      //unlock remappable pins
    switch(num){
        case 1: RPOR11bits.RP22R = 20; break;   //assign PWM3 (OC3) to RP22
        case 2: RPOR11bits.RP23R = 20; break;   //assign PWM3 (OC3) to RP23
        case 3: RPOR12bits.RP24R = 20; break;   //assign PWM3 (OC3) to RP24
        case 4: RPOR5bits.RP11R  = 20; break;   //assign PWM3 (OC3) to RP11
    }
    CloseOC3();                 //turn it off (PWM)
    ConfigIntOC3(OC_INT_OFF);   //no interrupt
    PPSLock;                    //lock remappable pins
}
///////////////////////////////////////////////////////////////////////////////

/*LEDport*/
///////////////////////////////////////////////////////////////////////////////
BOOL LED_Get(int num)
{
    unsigned char portData = 0;

    if(num > 8 || !num){ return FALSE; }

    portData  = (PORTE & (1<<(num-1)));
    portData >>= num-1;
    
    /*Since LEDs are sinked, we have to deal with inverse logic.
    * This XOR is used to compensate that*/
    portData ^= 1;

    return portData;    //1=LEDx is off, 0=LEDx is on.
}

void LED_Set(int num, BOOL state)
{
    if(num > 8 || !num){ return; }

    switch(num){        
        case 1: if(state){ LED1_SET = 0; }
                else     { LED1_SET = 1; }
                break;
        case 2: if(state){ LED2_SET = 0; }
                else     { LED2_SET = 1; }
                break;
        case 3: if(state){ LED3_SET = 0; }
                else     { LED3_SET = 1; }
                break;
        case 4: if(state){ LED4_SET = 0; }
                else     { LED4_SET = 1; }
                break;
        case 5: if(state){ LED5_SET = 0; }
                else     { LED5_SET = 1; }
                break;
        case 6: if(state){ LED6_SET = 0; }
                else     { LED6_SET = 1; }
                break;
        case 7: if(state){ LED7_SET = 0; }
                else     { LED7_SET = 1; }
                break;
        case 8: if(state){ LED8_SET = 0; }
                else     { LED8_SET = 1; }
                break;
    }
}

BYTE LEDport_Get(void)
{
    BYTE value = 0;

    value = PORTE;

    return value;
}

void LEDport_Set(unsigned char value, BOOL invert)
{
    if(invert){
        value ^= 0xFF;
    }

    LATE = value;
}

#if defined (AGUIJON_REV_4)
BOOL StatusLED_Get(unsigned char color)
{
    if(color == 1){
        return STATUS_LEDA_GET;
    }else if(color == 2){
        return STATUS_LEDB_GET;
    }
    return 0;
}

void StatusLED_Set(int color, BOOL state)
{
    switch(color){
        case 1: STATUS_LEDA_SET = (0 | state); break;
        case 2: STATUS_LEDB_SET = (0 | state); break;
        case 3:
            STATUS_LEDA_SET = (0 | state);
            STATUS_LEDB_SET = (0 | state);
            break;
    }
}
#endif
///////////////////////////////////////////////////////////////////////////////

/*Buzzer*/
///////////////////////////////////////////////////////////////////////////////
void Buzzer_On(int period, int duty_cycle)
{
    //period is given in microSeconds (uS)
    UINT32 duty = 0;
    UINT16 fixedPeriod = 0;

    if(period < 8000){
        fixedPeriod = (period * PWM_CONV_FACTOR);
    }else{
        fixedPeriod = 1000;
    }

    CloseOC2();
    if(duty_cycle && fixedPeriod){
        duty  = fixedPeriod;
        duty *= duty_cycle;
        duty /= 100;
        OpenOC2(OC_SYSCLK_SRC  | OC_CONTINUE_PULSE, OC_SYNC_TRIG_IN_CURR_OC, fixedPeriod, duty);
    }
}

inline void Buzzer_Off(void)
{
    CloseOC2();
}

void Buzzer_Chime(void)
{
    Buzzer_On(600,50);
    delayms(20);
    Buzzer_Off();

    delayms(10);

    Buzzer_On(600,50);
    delayms(20);
    Buzzer_Off();

    delayms(10);

    Buzzer_On(400,50);
    delayms(20);
    Buzzer_Off();
}
///////////////////////////////////////////////////////////////////////////////
