/********************************************************************
 FileName:    	realtime.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0 & rev4.0
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    RTCC Support File


 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             JCOG
  2.0   Updated with [VD] HammerHead libraries      JCOG

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "outputs.h"
#include "realtime.h"
#include <Rtcc.h>





///////////////////////////////////////
void __attribute__ ((interrupt,no_auto_psv)) _RTCCInterrupt(void)
{
    if(LED_Get(3) == OFF){ LED_Set(3,ON); }
    else { LED_Set(3,OFF); }
    
    IFS3bits.RTCIF = 0;  //clear the interrupt status
}

inline void RTCC_Enable(void)
{
    RCFGCALbits.RTCEN = 1;   //enable RTCC
}

inline void RTCC_Disable(void)
{
    RCFGCALbits.RTCEN = 0;   //disable RTCC
}

/*****************************************************************************
 * Function: RTCCUnlock
 *
 * Preconditions: None.
 *
 * Overview: The function allows a writing into the clock registers.
 *
 * Input: None.
 *
 * Output: None.
 *
 *****************************************************************************/
static void RTCC_Unlock(void)
{
    __builtin_write_RTCWEN(1); //set the RTCWREN bit
    asm volatile("bset	_RCFGCAL, #13");
    __builtin_write_RTCWEN(0); //set the RTCWREN bit
}

/*****************************************************************************
 * Function: RTCCSet
 *
 * Preconditions: None.
 *
 * Overview: This function sets the time, date, day of week, and year
 *
 * Input:
 *
 * Output: None.
 *
 *****************************************************************************/
static void RTCC_Set(void)
{
    IEC3bits.RTCIE  = 1;        //enable RTCC interrupt
    IPC15bits.RTCIP = 4;        //priority #5

    //Step 1: Unlock RTCC registers
    RTCC_Unlock();

    //Step 2: Configure RTCPTR Autodecrementing pointer in RCFGCAL register
    RCFGCALbits.RTCPTR = 3;	//setup RTCPTR pointer to max value

    //Step 3: Write Year, Month & day, weekday & hours, min & sec to RTCVAL in BCD format
    RTCVAL = 0x0000;         //unused  : Year
    RTCVAL = 0x0000;         //Month   : Day
    RTCVAL = 0x0000;         //Weekday : Hours
    RTCVAL = 0x0000;         //Minutes : Seconds

    //Step 4: In RCFGCAL enable RTCC
    RCFGCALbits.RTCEN = 0;   //disable RTCC

    //Step 5: Lock RTCC registers
//    RCFGCALbits.RTCWREN = 0;
}

/*****************************************************************************
 * Function: AlarmSet
 *
 * Preconditions: None.
 *
 * Overview: The function sets the alarm
 *
 * Input:
 *
 * Output: None.
 *
 *****************************************************************************/
static void RTCC_AlarmSet(void)
{
    //UnLock Alarm Registers
    RTCC_Unlock();

    //Configure ALCFGRPT, ALRMPTR Auto-decrementing pointer
    ALCFGRPTbits.ALRMPTR = 0;
    ALCFGRPTbits.CHIME   = 1;

    //Write Alarm Month & Day To ALRMVAL
    ALRMVAL = 0x0000;

    //Write Alarm Week Day & Hour To ALRMVAL
    ALRMVAL = 0x0000;

    //Write Alarm Minute & Second To ALRMVAL
    ALRMVAL = 0x0000;

    ALCFGRPTbits.AMASK = RTCC_ALRM_1_SEC;     //Configure Alarm frequency
    ALCFGRPTbits.ARPT  = 0xFF;  //Repeat alarm n times

    //Step 7: In ALCFGRPT, enable Alarm
    ALCFGRPTbits.ALRMEN = 1;    //enable alarm


    //  Lock Alarm Registers
//    RCFGCALbits.RTCWREN = 0;
}
/*****************************************************************************
 * Function: RTCCInit
 *
 * Preconditions: RTCCInit must be called before.
 *
 * Overview: Enable the oscillator for the RTCC
 *
 * Input: None.
 *
 * Output: None.
 *****************************************************************************/
void RTCC_Init(void)
{
    // Enables the LP OSC for RTCC operation
    __builtin_write_OSCCONL(0x02); 

    // Unlock sequence must take place for RTCEN to be written
    RCFGCAL = 0x0000;

    RTCC_AlarmSet();

    RTCC_Set();
}
