/********************************************************************
 FileName:    	timers.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0 & rev4.0
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Timers Support File


 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             JCOG
  2.0   Updated with [VD] HammerHead libraries      JCOG

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "timers.h"
#include "outputs.h"




///////////////////////////////////////
//void TIMER1_Init(unsigned int tick_Ms)
void Timer1_Init(void)
{
    T1CON = 0x0020;             //Stops the Timer1 and reset control reg. 1:64 ps
    TMR1  = 0x00; 		//Clear contents of the timer registers

    IPC0bits.T1IP = 0x02; 	//Setup Timer2 interrupt for desired priority level
    IFS0bits.T1IF = 0; 		//Clear the Timer1 interrupt status flag
    IEC0bits.T1IE = 1; 		//Enable Timer1 interrupts
    //clock source set to the internal instruction cycle
}

void Timer1_SetTick(unsigned int tick_ms)
{
    PR1 = tick_ms;//Load the Period register with predefined preset (timers.h)
}

inline void Timer1_Enable(void)
{
    T1CONbits.TON = 1;  //Start Timer1
}

inline void Timer1_Disable(void)
{
    T1CONbits.TON = 0;  //Stop Timer1
}

void __attribute__((__interrupt__, __shadow__,__no_auto_psv__)) _T1Interrupt(void)
{
#if defined(AGUIJON_REV_4)
    if(StatusLED_Get(YELLOW_LED) == OFF){
        StatusLED_Set(YELLOW_LED,ON);
    }else{
        StatusLED_Set(YELLOW_LED,OFF);
    }
#elif defined(AGUIJON_REV_3)
    if(LED_Get(1) == OFF){ LED_Set(1,ON); }
    else { LED_Set(1,OFF); }
#endif

    IFS0bits.T1IF = 0; //Reset Timer1 interrupt flag and Return from ISR
}


//void TIMER4_Init(unsigned int tickMS)
void Timer4_Init(void)
{
    T4CON = 0x0020;             //Stops the Timer4sand reset control reg. 1:64 ps
    TMR4  = 0x00; 		//Clear contents of the timer register

    IPC6bits.T4IP = 0x01;       //Setup Timer4 interrupt for desired priority level
    IFS1bits.T4IF = 0; 		//Clear the Timer4 interrupt status flag
    IEC1bits.T4IE = 1; 		//Enable Timer4 interrupts
    //clock source set to the internal instruction cycle
}

void Timer4_SetTick(unsigned int tick_ms)
{
    PR4 = tick_ms;//Load the Period register with predefined preset (timers.h)
}

inline void Timer4_Enable(void)
{
    T4CONbits.TON = 1;  //Start Timer4
}

inline void Timer4_Disable(void)
{
    T4CONbits.TON = 0;  //Stop Timer4
}

void __attribute__((__interrupt__, __shadow__,__no_auto_psv__)) _T4Interrupt(void)
{    
#if defined(AGUIJON_REV_4)
    if(StatusLED_Get(RED_LED) == OFF){
        StatusLED_Set(RED_LED,ON);
    }else{
        StatusLED_Set(RED_LED,OFF);
    }
#elif defined(AGUIJON_REV_3)
    if(LED_Get(2) == OFF){ LED_Set(2,ON); }
    else { LED_Set(2,OFF); }
#endif

    IFS1bits.T4IF = 0; //Reset Timer4 interrupt flag and Return from ISR
}

